---
title: User manual
---

<div class="callout">

<i class="fa fa-paint-roller fa-lg me-2" aria-hidden="true"></i>
**Under construction.**
Not much here right now, sorry about that.

While this is under way, you can start by looking at the source code for building
this very website in the `doc` folder of
[`leouieda/nene`](https://github.com/leouieda/nene) on GitHub.
  
There are also these examples of websites built with Nēnē:

* [compgeolab.org](https://www.compgeolab.org) (source code: [compgeolab/website](https://github.com/compgeolab/website))
* [acarolcolombo.com](https://www.acarolcolombo.com) (source code: [acarolcolombo/website](https://github.com/acarolcolombo/website))

</div>

## Command line usage

Build a website from sources in the current directory:

```bash
nene
```

To serve the website locally for development:

```bash
nene --serve
```

Print a help message with all available options:

```bash
nene --help
```
